@@ -54,6 +54,7 @@ import org.opennms.core.ipc.sink.api.SinkModule;
 import org.opennms.core.ipc.sink.api.SyncDispatcher;
 import org.opennms.core.ipc.sink.common.AbstractMessageDispatcherFactory;
 import org.opennms.core.test.MockLogAppender;
+import org.osgi.framework.BundleContext;
 
 import com.google.common.util.concurrent.RateLimiter;
 
@@ -71,6 +72,16 @@ public class AggregationTest {
         public <S extends Message, T extends Message> void dispatch(SinkModule<S, T> module, Void metadata, T message) {
             dispatchedMessages.add(message);
         }
+
+        @Override
+        public String getMetricDomain() {
+            return AggregationTest.class.getPackage().getName();
+        }
+
+        @Override
+        public BundleContext getBundleContext() {
+            return null;
+        }
     };
 
     @Before
@@ -405,6 +416,16 @@ public class AggregationTest {
             return null;
         }
 
+        @Override
+        public byte[] marshalSingleMessage(S message) {
+            return null;
+        }
+
+        @Override
+        public S unmarshalSingleMessage(byte[] message) {
+            return null;
+        }
+
         @Override
         public AsyncPolicy getAsyncPolicy() {
             return null;
