@@ -55,6 +55,16 @@ public class MockSinkModule<S extends Message, T extends Message> implements Sin
         return null;
     }
 
+    @Override
+    public byte[] marshalSingleMessage(S message) {
+        return new byte[0];
+    }
+
+    @Override
+    public S unmarshalSingleMessage(byte[] message) {
+        return null;
+    }
+
     @Override
     public AggregationPolicy<S, T, ?> getAggregationPolicy() {
         return null;
