@@ -1,8 +1,8 @@
 /*******************************************************************************
  * This file is part of OpenNMS(R).
  *
- * Copyright (C) 2011-2014 The OpenNMS Group, Inc.
- * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
+ * Copyright (C) 2011-2017 The OpenNMS Group, Inc.
+ * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
  *
  * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
  *
@@ -32,19 +32,27 @@ import java.io.IOException;
 import java.net.InetAddress;
 import java.net.SocketException;
 import java.net.UnknownHostException;
+import java.time.Duration;
+import java.time.LocalDateTime;
 import java.util.Arrays;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.concurrent.CompletableFuture;
-import java.util.concurrent.ExecutionException;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
+import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ThreadFactory;
+import java.util.concurrent.TimeUnit;
 
+import org.opennms.core.logging.Logging;
 import org.opennms.netmgt.snmp.CollectionTracker;
 import org.opennms.netmgt.snmp.SnmpAgentConfig;
 import org.opennms.netmgt.snmp.SnmpConfiguration;
+import org.opennms.netmgt.snmp.SnmpException;
 import org.opennms.netmgt.snmp.SnmpObjId;
 import org.opennms.netmgt.snmp.SnmpStrategy;
 import org.opennms.netmgt.snmp.SnmpTrapBuilder;
@@ -85,7 +93,6 @@ import org.snmp4j.smi.VariableBinding;
 import org.snmp4j.transport.DefaultUdpTransportMapping;
 
 public class Snmp4JStrategy implements SnmpStrategy {
-
     private static final transient Logger LOG = LoggerFactory.getLogger(Snmp4JStrategy.class);
 
     private static final ExecutorService REAPER_EXECUTOR = Executors.newCachedThreadPool(new ThreadFactory() {
@@ -103,6 +110,12 @@ public class Snmp4JStrategy implements SnmpStrategy {
 
     private Snmp4JValueFactory m_valueFactory;
 
+    private static ScheduledExecutorService s_sessionStatsExecutor;
+    private static ConcurrentHashMap<Snmp, SessionInfo> s_sessions;
+    private static boolean s_trackSessions = Boolean.getBoolean("org.opennms.core.snmp.trackSessions");
+    private static long s_trackSummaryDelay = Long.getLong("org.opennms.core.snmp.trackSummaryDelay", 60);
+    private static long s_trackSummaryLimit = Long.getLong("org.opennms.core.snmp.trackSummaryLimit", 10);
+
     /**
      * Initialize for v3 communications
      */
@@ -283,7 +296,7 @@ public class Snmp4JStrategy implements SnmpStrategy {
         send(agentConfig, pdu, expectResponse, future);
         try {
             return future.get();
-        } catch (ExecutionException | InterruptedException e) {
+        } catch (final Exception e) {
             LOG.error(e.getMessage(), e);
             return new SnmpValue[] { null };
         }
@@ -294,30 +307,32 @@ public class Snmp4JStrategy implements SnmpStrategy {
 
         try {
             session = agentConfig.createSnmpSession();
-        } catch (IOException e) {
+            Snmp4JStrategy.trackSession(session);
+        } catch (final Exception e) {
             LOG.error("send: Could not create SNMP session for agent {}", agentConfig, e);
-            future.completeExceptionally(new Exception("Could not create SNMP session for agent"));
+            future.completeExceptionally(new SnmpException("Could not create SNMP session for agent", e));
             return;
         }
 
         if (expectResponse) {
             try {
                 session.listen();
-            } catch (IOException e) {
+            } catch (final Exception e) {
                 closeQuietly(session);
                 LOG.error("send: error setting up listener for SNMP responses", e);
-                future.completeExceptionally(new Exception("error setting up listener for SNMP responses"));
+                future.completeExceptionally(new SnmpException("error setting up listener for SNMP responses", e));
                 return;
             }
 
             try {
-                session.send(pdu, agentConfig.getTarget(), null, new ResponseListener() {
+                final Snmp mySession = session;
+                mySession.send(pdu, agentConfig.getTarget(), null, new ResponseListener() {
                     @Override
-                    public void onResponse(ResponseEvent responseEvent) {
+                    public void onResponse(final ResponseEvent responseEvent) {
                         try {
                             future.complete(processResponse(agentConfig, responseEvent));
-                        } catch (Exception e) {
-                            future.completeExceptionally(e);
+                        } catch (final Exception e) {
+                            future.completeExceptionally(new SnmpException(e));
                         } finally {
                             // Close the tracker using a separate thread
                             // This allows the SnmpWalker to clean up properly instead
@@ -325,7 +340,7 @@ public class Snmp4JStrategy implements SnmpStrategy {
                             REAPER_EXECUTOR.submit(new Runnable() {
                                 @Override
                                 public void run() {
-                                    closeQuietly(session);
+                                    closeQuietly(mySession);
                                 }
                             });
                         }
@@ -344,9 +359,10 @@ public class Snmp4JStrategy implements SnmpStrategy {
                 future.complete(null);
             } catch (final Exception e) {
                 LOG.error("send: error during SNMP operation", e);
-                future.completeExceptionally(e);
+                future.completeExceptionally(new SnmpException(e));
             } finally {
                 closeQuietly(session);
+                Snmp4JStrategy.reapSession(session);
             }
         }
     }
@@ -361,7 +377,7 @@ public class Snmp4JStrategy implements SnmpStrategy {
         } else {
             // TODO should this throw an exception?  This situation is fairly bogus and probably signifies a coding error.
             if (oids.length != values.length) {
-                Exception e = new Exception("This is a bogus exception so we can get a stack backtrace");
+                Exception e = new SnmpException("PDU values do not match OIDs");
                 LOG.error("PDU to prepare has object values but not the same number as there are OIDs.  There are {} OIDs and {} object values.", oids.length, values.length, e);
                 return null;
             }
@@ -373,7 +389,7 @@ public class Snmp4JStrategy implements SnmpStrategy {
         
         // TODO should this throw an exception?  This situation is fairly bogus.
         if (pdu.getVariableBindings().size() != oids.length) {
-            Exception e = new Exception("This is a bogus exception so we can get a stack backtrace");
+            Exception e = new SnmpException("PDU bindings do not match OIDs");
             LOG.error("Prepared PDU does not have as many variable bindings as there are OIDs.  There are {} OIDs and {} variable bindings.", oids.length,pdu.getVariableBindings(), e);
             return null;
         }
@@ -450,6 +466,9 @@ public class Snmp4JStrategy implements SnmpStrategy {
 		}
 
         public void setSession(final Snmp trapSession) {
+            if (m_trapSession != null && m_trapSession != trapSession) {
+                LOG.warn("replacing existing session {} with {}", m_trapSession, trapSession);
+            }
             m_trapSession = trapSession;
         }
         
@@ -521,6 +540,7 @@ public class Snmp4JStrategy implements SnmpStrategy {
 
         info.setTransportMapping(transport);
         Snmp snmp = new Snmp(transport);
+        Snmp4JStrategy.trackSession(snmp);
         snmp.addCommandResponder(trapNotifier);
 
         if (snmpUsers != null) {
@@ -570,14 +590,30 @@ public class Snmp4JStrategy implements SnmpStrategy {
 
     @Override
     public void unregisterForTraps(final TrapNotificationListener listener, InetAddress address, int snmpTrapPort) throws IOException {
-        RegistrationInfo info = s_registrations.remove(listener);
-        closeQuietly(info.getSession());
+        final RegistrationInfo info = s_registrations.remove(listener);
+        final Snmp session = info.getSession();
+        try {
+            session.close();
+        } catch (final IOException e) {
+            LOG.error("session error unregistering for traps", e);
+            throw e;
+        } finally {
+            Snmp4JStrategy.reapSession(session);
+        }
     }
 
     @Override
     public void unregisterForTraps(final TrapNotificationListener listener, final int snmpTrapPort) throws IOException {
-        RegistrationInfo info = s_registrations.remove(listener);
-        closeQuietly(info.getSession());
+        final RegistrationInfo info = s_registrations.remove(listener);
+        final Snmp session = info.getSession();
+        try {
+            session.close();
+        } catch (final IOException e) {
+            LOG.error("session error unregistering for traps", e);
+            throw e;
+        } finally {
+            Snmp4JStrategy.reapSession(session);
+        }
     }
 
     @Override
@@ -624,10 +660,11 @@ public class Snmp4JStrategy implements SnmpStrategy {
 			String securityName, String authPassPhrase, String authProtocol,
 			String privPassPhrase, String privProtocol, PDU pdu) throws UnknownHostException, Exception {
 			
-		if (! (pdu instanceof ScopedPDU)) 
-				throw new Exception();
+		if (! (pdu instanceof ScopedPDU)) {
+		    throw new SnmpException("PDU is not a ScopedPDU (this should not happen)");
+		}
 
-			SnmpAgentConfig config = new SnmpAgentConfig();
+		SnmpAgentConfig config = new SnmpAgentConfig();
 	        config.setAddress(InetAddress.getByName(address));
 	        config.setPort(port);
 	        config.setVersion(SnmpAgentConfig.VERSION3);
@@ -656,7 +693,8 @@ public class Snmp4JStrategy implements SnmpStrategy {
     public void sendTest(String agentAddress, int port, String community, PDU pdu) {
         for (RegistrationInfo info : s_registrations.values()) {
             if (port == info.getPort()) {
-                Snmp snmp = info.getSession();
+                final Snmp snmp = info.getSession();
+                Snmp4JStrategy.trackSession(snmp);
                 MessageDispatcher dispatcher = snmp.getMessageDispatcher();
                 TransportMapping<UdpAddress> transport = info.getTransportMapping();
                 
@@ -681,6 +719,8 @@ public class Snmp4JStrategy implements SnmpStrategy {
             session.close();
         } catch (IOException e) {
             LOG.error("error closing SNMP connection", e);
+        } finally {
+            Snmp4JStrategy.reapSession(session);
         }
     }
 
@@ -688,4 +728,135 @@ public class Snmp4JStrategy implements SnmpStrategy {
 	public byte[] getLocalEngineID() {
 		return MPv3.createLocalEngineID();
 	}
+
+        private static void assertTrackingInitialized() {
+            if (s_sessions == null) {
+                s_sessions = new ConcurrentHashMap<>();
+                s_sessionStatsExecutor = Executors.newSingleThreadScheduledExecutor();
+                s_sessionStatsExecutor.scheduleAtFixedRate(new Runnable() {
+                    @Override public void run() {
+                        logSessionStats();
+                    }
+                }, s_trackSummaryDelay, s_trackSummaryDelay, TimeUnit.SECONDS);
+            }
+        }
+
+        public static void trackSession(final Snmp session) {
+            if (!s_trackSessions || session == null) return;
+            Logging.withPrefix("snmp", () -> {
+                assertTrackingInitialized();
+                if (s_sessions.containsKey(session)) {
+                    LOG.warn("track: session {} is already tracked -- overwriting", s_sessions.get(session));
+                }
+                final SessionInfo ts = new SessionInfo(session);
+                LOG.debug("track: tracking session {}", ts);
+                s_sessions.put(session, ts);
+            });
+        }
+
+        public static void reapSession(final Snmp session) {
+            if (!s_trackSessions || session == null) return;
+            Logging.withPrefix("snmp", () -> {
+                assertTrackingInitialized();
+                if (!s_sessions.containsKey(session)) {
+                    LOG.warn("reap: session {} is not being tracked", session, new Exception());
+                } else {
+                    LOG.debug("reap: reaping session {}", s_sessions.get(session));
+                }
+                s_sessions.remove(session);
+            });
+        }
+
+        private static void logSessionStats() {
+            LOG.debug("SNMP session tracker: {} sessions being tracked on {} unique threads", s_sessions.size(), s_sessions.values().stream().map(si -> {
+                return si.getThread();
+            }).distinct().count());
+            s_sessions.values().stream().sorted(new Comparator<SessionInfo>() {
+                @Override
+                public int compare(final SessionInfo o1, final SessionInfo o2) {
+                    return o1.getStart().compareTo(o2.getStart());
+                }
+            }).limit(s_trackSummaryLimit).forEach((si) -> {
+                LOG.debug("SNMP session tracker: active session: {}", si);
+            });
+        }
+
+        private static class SessionInfo implements Comparable<SessionInfo> {
+            private final Snmp m_session;
+            private final StackTraceElement[] m_stackTrace;
+            private final Thread m_thread;
+            private final LocalDateTime m_start;
+
+            public SessionInfo(final Snmp session) {
+                m_session = session;
+                m_stackTrace = new Exception().getStackTrace();
+                m_thread = Thread.currentThread();
+                m_start = LocalDateTime.now();
+            }
+
+            public Thread getThread() {
+                return m_thread;
+            }
+
+            public LocalDateTime getStart() {
+                return m_start;
+            }
+
+            public String getOutsideCaller() {
+                for (final StackTraceElement ste : m_stackTrace) {
+                    final String name = ste.getClassName();
+                    if (!name.startsWith("org.opennms.netmgt.snmp.snmp4j") && !name.startsWith("org.opennms.core.logging") && !name.startsWith("org.opennms.netmgt.snmp.SnmpUtils")) {
+                        return ste.toString();
+                    }
+                }
+                LOG.warn("unable to determine non-snmp4j caller from stack trace: {}", Arrays.asList(m_stackTrace));
+                return m_stackTrace[0].toString();
+            }
+            @Override
+            public int hashCode() {
+                return Objects.hash(m_session, m_thread);
+            }
+
+            @Override
+            public boolean equals(Object obj) {
+                if (this == obj) {
+                    return true;
+                }
+                if (obj == null) {
+                    return false;
+                }
+                if (getClass() != obj.getClass()) {
+                    return false;
+                }
+                final SessionInfo that = (SessionInfo) obj;
+                return Objects.equals(this.m_session, that.m_session) &&
+                        Objects.equals(this.m_stackTrace, that.m_stackTrace) &&
+                        Objects.equals(this.m_thread, that.m_thread);
+            }
+
+            @Override
+            public int compareTo(final SessionInfo that) {
+                if (this.m_session.hashCode() < that.m_session.hashCode()) {
+                    return -1;
+                } else if (this.m_session.hashCode() > that.m_session.hashCode()) {
+                    return 1;
+                }
+                if (this.m_stackTrace.hashCode() < that.m_stackTrace.hashCode()) {
+                    return -1;
+                } else if (this.m_stackTrace.hashCode() > that.m_stackTrace.hashCode()) {
+                    return 1;
+                }
+                if (this.m_thread.hashCode() < that.m_thread.hashCode()) {
+                    return -1;
+                } else if (this.m_thread.hashCode() > that.m_thread.hashCode()) {
+                    return 1;
+                }
+                return 0;
+            }
+
+            @Override
+            public String toString() {
+                return "SessionInfo[session=" + m_session + ", caller=" + getOutsideCaller() + ", thread=" + m_thread.getName() + ", age=" + Duration.between(m_start, LocalDateTime.now()).getSeconds() + "s]";
+            }
+        }
 }
