@@ -29,6 +29,7 @@
 package org.opennms.netmgt.telemetry.itests;
 
 import static com.jayway.awaitility.Awaitility.await;
+import static org.hamcrest.CoreMatchers.containsString;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.junit.Assert.assertTrue;
 
@@ -37,9 +38,17 @@ import java.io.IOException;
 import java.net.DatagramPacket;
 import java.net.DatagramSocket;
 import java.net.InetAddress;
+import java.nio.charset.StandardCharsets;
+import java.nio.file.FileSystem;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import java.nio.file.Paths;
+import java.nio.file.StandardCopyOption;
+import java.nio.file.WatchService;
+import java.nio.file.attribute.FileTime;
 import java.util.concurrent.TimeUnit;
 
+import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -85,7 +94,8 @@ import com.google.common.io.Resources;
         "classpath:/META-INF/opennms/applicationContext-daemon.xml",
         "classpath:/META-INF/opennms/mockEventIpcManager.xml",
         "classpath:/META-INF/opennms/applicationContext-queuingservice-mq-vm.xml",
-        "classpath:/META-INF/opennms/applicationContext-ipc-sink-server-camel.xml",
+        "classpath:/META-INF/opennms/applicationContext-ipc-sink-camel-server.xml",
+        "classpath:/META-INF/opennms/applicationContext-ipc-sink-camel-client.xml",
         "classpath:/META-INF/opennms/applicationContext-collectionAgentFactory.xml",
         "classpath:/META-INF/opennms/applicationContext-jtiAdapterFactory.xml",
         "classpath:/META-INF/opennms/applicationContext-telemetryDaemon.xml"
@@ -109,11 +119,14 @@ public class JtiIT {
     @Rule
     public TemporaryFolder tempFolder = new TemporaryFolder();
 
+    public File scriptFile;
+
     private File rrdBaseDir;
 
     @Before
     public void setUp() throws IOException {
         rrdBaseDir = tempFolder.newFolder("rrd");
+        scriptFile  = tempFolder.newFile("script-file.groovy");
 
         NetworkBuilder nb = new NetworkBuilder();
         nb.addNode("R1")
@@ -151,6 +164,48 @@ public class JtiIT {
                 .resolve(Paths.get("1", "ge_0_0_3", "ifOutOctets.jrb")).toFile().canRead(), equalTo(true));
     }
 
+    @Test
+    public void testScriptFileReload() throws Exception {
+        final int port = 50001;
+
+        // Use our custom configuration
+        updateDaoWithConfig(getConfig(port));
+
+        // Start the daemon
+        telemetryd.start();
+
+        String content = new String(Files.readAllBytes(scriptFile.toPath()), StandardCharsets.UTF_8);
+        Assert.assertThat(content, containsString("ifOutOctets"));
+
+        // Send a JTI payload via a UDP socket
+        final byte[] jtiMsgBytes = Resources.toByteArray(Resources.getResource("jti_15.1F4_ifd_ae_40000.raw"));
+        InetAddress address = InetAddressUtils.getLocalHostAddress();
+        DatagramPacket packet = new DatagramPacket(jtiMsgBytes, jtiMsgBytes.length, address, port);
+        DatagramSocket socket = new DatagramSocket();
+        socket.send(packet);
+
+        // Wait until the JRB archive is created
+        await().atMost(30, TimeUnit.SECONDS).until(() -> rrdBaseDir.toPath()
+                .resolve(Paths.get("1", "ge_0_0_3", "ifOutOctets.jrb")).toFile().canRead(), equalTo(true));
+
+        // now change script file
+        content = content.replaceAll("ifOutOctets", "FooBar");
+        Files.write(scriptFile.toPath(), content.getBytes(StandardCharsets.UTF_8));
+        //Files.setLastModifiedTime(newFile.toPath(), FileTime.fromMillis(System.currentTimeMillis()));
+
+        await().pollDelay(1, TimeUnit.SECONDS).atMost(30, TimeUnit.SECONDS).until(() -> {
+            final InetAddress newAddress = InetAddressUtils.getLocalHostAddress();
+            final DatagramPacket newPacket = new DatagramPacket(jtiMsgBytes, jtiMsgBytes.length, newAddress, port);
+            final DatagramSocket newSocket = new DatagramSocket();
+            newSocket.send(newPacket);
+
+            return rrdBaseDir.toPath()
+                    .resolve(Paths.get("1", "ge_0_0_3", "FooBar.jrb"))
+                    .toFile()
+                    .canRead();
+        }, equalTo(true));
+    }
+
     private void updateDaoWithConfig(TelemetrydConfiguration config) throws IOException {
         final File tempFile = tempFolder.newFile();
         JaxbUtils.marshal(config, tempFile);
@@ -158,7 +213,7 @@ public class JtiIT {
         telemetrydConfigDao.afterPropertiesSet();
     }
 
-    private TelemetrydConfiguration getConfig(int port) {
+    private TelemetrydConfiguration getConfig(int port) throws IOException {
         TelemetrydConfiguration telemetrydConfig = new TelemetrydConfiguration();
 
         Protocol jtiProtocol = new Protocol();
@@ -176,10 +231,17 @@ public class JtiIT {
         jtiGbpAdapter.setName("JTI-GBP");
         jtiGbpAdapter.setClassName(JtiGpbAdapter.class.getCanonicalName());
 
-        File script = Paths.get(System.getProperty("opennms.home"),
-                "etc", "telemetryd-adapters", "junos-telemetry-interface.groovy").toFile();
-        assertTrue("Can't read: " + script.getAbsolutePath(), script.canRead());
-        jtiGbpAdapter.getParameters().add(new Parameter("script", script.getAbsolutePath()));
+        Files.copy(
+                Paths.get(System.getProperty("opennms.home"),
+                        "etc",
+                        "telemetryd-adapters",
+                        "junos-telemetry-interface.groovy"),
+                scriptFile.toPath(),
+                StandardCopyOption.REPLACE_EXISTING
+        );
+
+        assertTrue("Can't read: " + scriptFile.getAbsolutePath(), scriptFile.canRead());
+        jtiGbpAdapter.getParameters().add(new Parameter("script", scriptFile.getAbsolutePath()));
         jtiProtocol.getAdapters().add(jtiGbpAdapter);
 
         Package jtiDefaultPkg = new Package();
