@@ -34,6 +34,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.stream.Collectors;
 
 import org.easymock.EasyMock;
 import org.junit.Assert;
@@ -60,18 +61,25 @@ import org.opennms.netmgt.dao.api.LldpLinkDao;
 import org.opennms.netmgt.dao.api.NodeDao;
 import org.opennms.netmgt.dao.api.OspfLinkDao;
 import org.opennms.netmgt.dao.api.SnmpInterfaceDao;
+import org.opennms.netmgt.dao.api.TopologyEntityCache;
 import org.opennms.netmgt.model.CdpElement;
 import org.opennms.netmgt.model.CdpLink;
+import org.opennms.netmgt.model.IpInterfaceTopologyEntity;
 import org.opennms.netmgt.model.IpNetToMedia;
 import org.opennms.netmgt.model.IsIsElement;
 import org.opennms.netmgt.model.IsIsLink;
 import org.opennms.netmgt.model.LldpElement;
+import org.opennms.netmgt.model.LldpElementTopologyEntity;
 import org.opennms.netmgt.model.LldpLink;
+import org.opennms.netmgt.model.LldpLinkTopologyEntity;
 import org.opennms.netmgt.model.NetworkBuilder;
+import org.opennms.netmgt.model.NodeTopologyEntity;
 import org.opennms.netmgt.model.OnmsIpInterface;
 import org.opennms.netmgt.model.OnmsNode;
 import org.opennms.netmgt.model.OnmsSnmpInterface;
 import org.opennms.netmgt.model.OspfLink;
+import org.opennms.netmgt.model.OspfLinkTopologyEntity;
+import org.opennms.netmgt.model.SnmpInterfaceTopologyEntity;
 import org.opennms.netmgt.model.topology.BroadcastDomain;
 import org.springframework.beans.factory.annotation.Autowired;
 
@@ -104,6 +112,9 @@ public class EnhancedLinkdMockDataPopulator {
     @Autowired
     private NodeDao m_nodeDao;
 
+    @Autowired
+    private TopologyEntityCache m_topologyEntityCache;
+
     @Autowired
     private SnmpInterfaceDao m_snmpInterfaceDao;
 
@@ -419,6 +430,16 @@ public class EnhancedLinkdMockDataPopulator {
         EasyMock.expect(m_lldpElementDao.findAll()).andReturn(getLldpElements()).anyTimes();
         EasyMock.expect(m_lldpLinkDao.findAll()).andReturn(getLinks()).anyTimes();
         EasyMock.expect(m_ospfLinkDao.findAll()).andReturn(getOspfLinks()).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getNodeTopolgyEntities()).andReturn(getVertices()).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getCdpLinkTopologyEntities()).andReturn(new ArrayList<>()).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getOspfLinkTopologyEntities()).andReturn(convertToOspf(getOspfLinks())).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getLldpLinkTopologyEntities()).andReturn(convertToLldp(getLinks())).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getIsIsLinkTopologyEntities()).andReturn(new ArrayList<>()).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getCdpElementTopologyEntities()).andReturn(new ArrayList<>()).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getIsIsElementTopologyEntities()).andReturn(new ArrayList<>()).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getLldpElementTopologyEntities()).andReturn(convertToLldpElements(getLldpElements())).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getSnmpInterfaceTopologyEntities()).andReturn(getSnmpInterfaceTopologyEntities()).anyTimes();
+        EasyMock.expect(m_topologyEntityCache.getIpInterfaceTopologyEntities()).andReturn(getIpInterfaceTopologyEntities()).anyTimes();
         EasyMock.expect(m_nodeDao.getAllLabelsById());
         EasyMock.expectLastCall().andReturn(getNodeLabelsById()).anyTimes();
         
@@ -436,11 +457,24 @@ public class EnhancedLinkdMockDataPopulator {
         EasyMock.replay(m_isisElementDao);
         EasyMock.replay(m_ospfLinkDao);
         EasyMock.replay(m_nodeDao);
+        EasyMock.replay(m_topologyEntityCache);
         EasyMock.replay(m_snmpInterfaceDao);
         EasyMock.replay(m_ipInterfaceDao);
         EasyMock.replay(m_ipNetToMediaDao);
     }
 
+    private List<LldpElementTopologyEntity> convertToLldpElements(List<LldpElement> lldpElements) {
+        return lldpElements.stream().map(LldpElementTopologyEntity::create).collect(Collectors.toList());
+    }
+
+    private List<OspfLinkTopologyEntity> convertToOspf(List<OspfLink> links) {
+        return links.stream().map(OspfLinkTopologyEntity::create).collect(Collectors.toList());
+    }
+
+    private List<LldpLinkTopologyEntity> convertToLldp(List<LldpLink> links) {
+        return links.stream().map(LldpLinkTopologyEntity::create).collect(Collectors.toList());
+    }
+
     public void tearDown() {
         EasyMock.reset(m_cdpLinkDao, m_isisLinkDao,m_bridgeTopologyDao);
         EasyMock.reset(m_cdpElementDao);
@@ -449,6 +483,7 @@ public class EnhancedLinkdMockDataPopulator {
         EasyMock.reset(m_lldpLinkDao);
         EasyMock.reset(m_ospfLinkDao);
         EasyMock.reset(m_nodeDao);
+        EasyMock.reset(m_topologyEntityCache);
         EasyMock.reset(m_snmpInterfaceDao);
         EasyMock.reset(m_ipInterfaceDao);
         EasyMock.reset(m_ipNetToMediaDao);
@@ -673,6 +708,14 @@ public class EnhancedLinkdMockDataPopulator {
         return m_nodes;
     }
 
+    public List<NodeTopologyEntity> getVertices() {
+        List<NodeTopologyEntity> vertices = new ArrayList();
+        for(OnmsNode node : m_nodes){
+            vertices.add(NodeTopologyEntity.toNodeTopologyInfo(node));
+        }
+        return vertices;
+    }
+
     public List<LldpElement> getLldpElements() {
         List<LldpElement> lldpelements = new ArrayList<>();
         for (OnmsNode node: m_nodes) 
@@ -682,12 +725,19 @@ public class EnhancedLinkdMockDataPopulator {
     
     public List<OnmsIpInterface> getOnmsIpInterfaces() {
         List<OnmsIpInterface> elements = new ArrayList<>();
-        for (OnmsNode node: m_nodes) 
+        for (OnmsNode node: m_nodes)
             elements.addAll(node.getIpInterfaces());
         return elements;
-        
     }
-    
+
+    public List<IpInterfaceTopologyEntity> getIpInterfaceTopologyEntities() {
+        List<IpInterfaceTopologyEntity> elements = new ArrayList<>();
+        for (OnmsIpInterface ipInterface : getOnmsIpInterfaces()) {
+            elements.add(IpInterfaceTopologyEntity.create(ipInterface));
+        }
+        return elements;
+    }
+
     public List<OnmsSnmpInterface> getOnmsSnmpInterfaces() {
         List<OnmsSnmpInterface> elements = new ArrayList<>();
         for (OnmsNode node: m_nodes) 
@@ -696,6 +746,14 @@ public class EnhancedLinkdMockDataPopulator {
         
     }
 
+    private List<SnmpInterfaceTopologyEntity> getSnmpInterfaceTopologyEntities(){
+        List<SnmpInterfaceTopologyEntity> elements = new ArrayList<>();
+        for (OnmsSnmpInterface ipInterface : getOnmsSnmpInterfaces()) {
+            elements.add(SnmpInterfaceTopologyEntity.create(ipInterface));
+        }
+        return elements;
+    }
+
     public void setNodes(List<OnmsNode> nodes) {
         m_nodes = nodes;
     }
