@@ -393,8 +393,6 @@ public class EnhancedLinkdTopologyProviderTest {
         m_databasePopulator.tearDown();
         if(m_topologyProvider != null) {
             m_topologyProvider.resetContainer();
-            m_topologyProvider.setLldpLinkDao(m_databasePopulator.getLldpLinkDao());
-            m_topologyProvider.setNodeDao(m_databasePopulator.getNodeDao());
         }
     }
 }
