@@ -106,6 +106,7 @@ import com.vmware.vim25.ws.Client;
  */
 public class VmwareViJavaAccess {
 
+    public final static int DEFAULT_TIMEOUT = 3000;
     /**
      * logging for VMware library VI Java
      */
@@ -132,6 +133,8 @@ public class VmwareViJavaAccess {
 
     private static ServiceInstancePool m_serviceInstancePool = new ServiceInstancePool();
 
+    private int m_timeout = DEFAULT_TIMEOUT;
+
     /**
      * Constructor for creating a instance for a given server and credentials.
      *
@@ -194,6 +197,10 @@ public class VmwareViJavaAccess {
         m_password = vmwareServer.getPassword();
     }
 
+    public int getTimeout() {
+        return m_timeout;
+    }
+
     /**
      * Connects to the server.
      *
@@ -222,6 +229,8 @@ public class VmwareViJavaAccess {
                     if (client != null) {
                         client.setConnectTimeout(timeout);
                         client.setReadTimeout(timeout);
+                        m_timeout = timeout;
+                        logger.debug("Set VMware service instance timeout to " + timeout + " ms.");
                         return true;
                     }
                 }
@@ -633,4 +642,8 @@ public class VmwareViJavaAccess {
             }
         }
     }
+
+    public static void setServiceInstancePool(final ServiceInstancePool serviceInstancePool) {
+        m_serviceInstancePool = serviceInstancePool;
+    }
 }
