@@ -334,11 +334,6 @@ public class ConfigTesterTest {
         testConfigFile("opennms-datasources.xml");
     }
 
-    @Test
-    public void testOpennmsServer() {
-        testConfigFile("opennms-server.xml");
-    }
-
     @Test
     public void testOpennms() {
         testConfigFile("opennms.properties");
