@@ -159,7 +159,7 @@ public class ResourceDaoIntegrityIT implements InitializingBean {
 
         m_easyMockUtils.replayAll();
         InputStream stream = ConfigurationTestUtils.getInputStreamForResource(this, "/collectdconfiguration-testdata.xml");
-        m_collectdConfig = new CollectdConfigFactory(stream, "localhost", false);
+        m_collectdConfig = new CollectdConfigFactory(stream);
         m_easyMockUtils.verifyAll();
 
         m_resourceStorageDao.setRrdDirectory(m_tempFolder.getRoot());
