@@ -736,4 +736,10 @@ public class OnmsFeatureKarafIT extends KarafTestCase {
 		installFeature("internal-plugins-descriptor");
 		System.out.println(executeCommand("feature:list -i"));
 	}
+    @Ignore("Failing since bumping 23.0.0 to 24.0.0")
+    @Test
+    public void testInstallFeatureOpennmsSituationFeedback() {
+        installFeature("opennms-dao-api"); // System classpath
+        installFeature("opennms-situation-feedback");
+    }
 }
