@@ -39,8 +39,14 @@ import static org.opennms.netmgt.nb.NmsNetworkBuilder.MUMBAI_SYSOID;
 import static org.opennms.netmgt.nb.NmsNetworkBuilder.SWITCH1_IP;
 import static org.opennms.netmgt.nb.NmsNetworkBuilder.SWITCH1_NAME;
 import static org.opennms.netmgt.nb.NmsNetworkBuilder.SWITCH1_SYSOID;
+import static org.opennms.core.utils.InetAddressUtils.str;
 
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
+import java.util.Set;
 
 import org.junit.Test;
 import org.opennms.core.utils.InetAddressUtils;
@@ -48,11 +54,18 @@ import org.opennms.netmgt.dao.api.MonitoringLocationDao;
 import org.opennms.netmgt.model.BridgeBridgeLink;
 import org.opennms.netmgt.model.BridgeElement;
 import org.opennms.netmgt.model.BridgeMacLink;
-import org.opennms.netmgt.model.BridgeMacLink.BridgeDot1qTpFdbStatus;
+import org.opennms.netmgt.model.OnmsIpInterface;
+import org.opennms.netmgt.model.BridgeMacLink.BridgeMacLinkType;
+import org.opennms.netmgt.model.IpNetToMedia;
+import org.opennms.netmgt.model.IpNetToMedia.IpNetToMediaType;
+import org.opennms.netmgt.model.topology.BridgeForwardingTableEntry.BridgeDot1qTpFdbStatus;
 import org.opennms.netmgt.model.NetworkBuilder;
 import org.opennms.netmgt.model.OnmsNode;
 import org.opennms.netmgt.model.OnmsNode.NodeType;
 import org.opennms.netmgt.model.monitoringLocations.OnmsMonitoringLocation;
+import org.opennms.netmgt.model.topology.BridgeForwardingTableEntry;
+import org.opennms.netmgt.model.topology.BridgePort;
+import org.opennms.netmgt.model.topology.BridgeTopologyException;
 import org.opennms.netmgt.model.topology.BroadcastDomain;
 import org.opennms.netmgt.model.topology.SharedSegment;
 import org.opennms.netmgt.nb.Nms10205bNetworkBuilder;
@@ -108,11 +121,11 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         OneBridgeCompleteTopology topology = new OneBridgeCompleteTopology();
         m_nodeDao.save(topology.nodeA);
         
-        m_linkd.getQueryManager().updateBft(topology.nodeAId, topology.bftA);
+        m_linkd.getQueryManager().store(topology.nodeAId, new ArrayList<BridgeForwardingTableEntry>(topology.bftA));
         
-        List<BridgeMacLink> links = m_linkd.getQueryManager().useBridgeTopologyUpdateBFT(topology.nodeAId);
+        Set<BridgeForwardingTableEntry> links = m_linkd.getQueryManager().useBridgeTopologyUpdateBFT(topology.nodeAId);
         assertEquals(topology.bftA.size(), links.size());
-        for (BridgeMacLink link: links) {
+        for (BridgeForwardingTableEntry link: links) {
             assertEquals(BridgeDot1qTpFdbStatus.DOT1D_TP_FDB_STATUS_LEARNED, link.getBridgeDot1qTpFdbStatus());
             System.err.println(link.printTopology());
         }
@@ -284,7 +297,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
     }
     
     @Test 
-    public void testLoadTopology() {
+    public void testLoadTopology() throws BridgeTopologyException {
         final OnmsMonitoringLocation location = new OnmsMonitoringLocation(MonitoringLocationDao.DEFAULT_MONITORING_LOCATION_ID, MonitoringLocationDao.DEFAULT_MONITORING_LOCATION_ID);
         ABCTopology topology = new ABCTopology();
         OnmsNode lnodeA = topology.nodeA;
@@ -365,7 +378,6 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         delink.setDesignatedNode(nodeE);
         delink.setDesignatedPort(54);
         delink.setBridgeBridgeLinkLastPollTime(delink.getBridgeBridgeLinkCreateTime());
-        m_bridgeBridgeLinkDao.save(delink);
 
         BridgeBridgeLink ablink = new BridgeBridgeLink();
         ablink.setNode(nodeA);
@@ -373,7 +385,6 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         ablink.setDesignatedNode(nodeB);
         ablink.setDesignatedPort(topology.portBA);
         ablink.setBridgeBridgeLinkLastPollTime(ablink.getBridgeBridgeLinkCreateTime());
-        m_bridgeBridgeLinkDao.save(ablink);
 
         BridgeBridgeLink bclink = new BridgeBridgeLink();
         bclink.setNode(nodeC);
@@ -381,94 +392,110 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         bclink.setDesignatedNode(nodeB);
         bclink.setDesignatedPort(topology.portBC);
         bclink.setBridgeBridgeLinkLastPollTime(ablink.getBridgeBridgeLinkCreateTime());
-        m_bridgeBridgeLinkDao.save(bclink);
         
         BridgeMacLink forward = new BridgeMacLink();
         forward.setNode(nodeB);
         forward.setBridgePort(topology.portBA);
         forward.setMacAddress(topology.macA);
+        forward.setLinkType(BridgeMacLinkType.BRIDGE_FORWARDER);
         forward.setBridgeMacLinkLastPollTime(forward.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(forward);
 
         BridgeMacLink sharedB = new BridgeMacLink();
         sharedB.setNode(nodeB);
         sharedB.setBridgePort(topology.portBC);
         sharedB.setMacAddress(topology.shar);
+        sharedB.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         sharedB.setBridgeMacLinkLastPollTime(sharedB.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(sharedB);
-
-        BridgeMacLink sharedC = new BridgeMacLink();
-        sharedC.setNode(nodeC);
-        sharedC.setBridgePort(topology.portCB);
-        sharedC.setMacAddress(topology.shar);
-        sharedC.setBridgeMacLinkLastPollTime(sharedC.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(sharedC);
         
         BridgeMacLink mac1 = new BridgeMacLink();
         mac1.setNode(nodeA);
         mac1.setBridgePort(topology.portA);
         mac1.setMacAddress(topology.mac1);
+        mac1.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac1.setBridgeMacLinkLastPollTime(mac1.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(mac1);
 
         BridgeMacLink mac2 = new BridgeMacLink();
         mac2.setNode(nodeB);
         mac2.setBridgePort(topology.portB);
         mac2.setMacAddress(topology.mac2);
+        mac2.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac2.setBridgeMacLinkLastPollTime(mac2.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(mac2);
 
         BridgeMacLink mac3 = new BridgeMacLink();
         mac3.setNode(nodeC);
         mac3.setBridgePort(topology.portC);
         mac3.setMacAddress(topology.mac3);
+        mac3.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac3.setBridgeMacLinkLastPollTime(mac3.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(mac3);
         
-        BridgeMacLink sharedD = new BridgeMacLink();
-        sharedD.setNode(nodeD);
-        sharedD.setBridgePort(45);
-        sharedD.setMacAddress(topology.shar);
-        sharedD.setBridgeMacLinkLastPollTime(sharedD.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(sharedD);
-
         BridgeMacLink sharedE = new BridgeMacLink();
         sharedE.setNode(nodeE);
         sharedE.setBridgePort(54);
         sharedE.setMacAddress(topology.shar);
+        sharedE.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         sharedE.setBridgeMacLinkLastPollTime(sharedE.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(sharedE);
 
         BridgeMacLink sharedK = new BridgeMacLink();
         sharedK.setNode(nodeK);
         sharedK.setBridgePort(1099);
         sharedK.setMacAddress(topology.shar);
+        sharedK.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         sharedK.setBridgeMacLinkLastPollTime(sharedK.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(sharedK);
 
         BridgeMacLink macK = new BridgeMacLink();
         macK.setNode(nodeK);
         macK.setBridgePort(1099);
         macK.setMacAddress("1234567800aa");
+        macK.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         macK.setBridgeMacLinkLastPollTime(macK.getBridgeMacLinkCreateTime());
-        m_bridgeMacLinkDao.save(macK);
 
-        m_bridgeMacLinkDao.flush();
+        m_bridgeBridgeLinkDao.save(delink);
+        m_bridgeBridgeLinkDao.save(ablink);
+        m_bridgeBridgeLinkDao.save(bclink);
         m_bridgeBridgeLinkDao.flush();
-        assertEquals(10, m_bridgeMacLinkDao.countAll());
         assertEquals(3, m_bridgeBridgeLinkDao.countAll());
+
         
+        m_bridgeMacLinkDao.save(forward);
+        m_bridgeMacLinkDao.save(sharedB);
+        m_bridgeMacLinkDao.save(mac1);
+        m_bridgeMacLinkDao.save(mac2);
+        m_bridgeMacLinkDao.save(mac3);
+
+        m_bridgeMacLinkDao.save(sharedE);
+        
+        m_bridgeMacLinkDao.save(sharedK);
+        m_bridgeMacLinkDao.save(macK);
+        
+        m_bridgeMacLinkDao.flush();
+        
+        assertEquals(8, m_bridgeMacLinkDao.countAll());
+        
+        for (BridgeMacLink maclink: m_bridgeMacLinkDao.findAll()) {
+            System.err.println(maclink.printTopology());
+        }
+
+        for (BridgeBridgeLink bblink: m_bridgeBridgeLinkDao.findAll()) {
+            System.err.println(bblink.printTopology());
+        }
+
         assertNotNull(m_bridgeTopologyDao);
+        
         m_linkd.getQueryManager().loadBridgeTopology();
 
+        for (BroadcastDomain bd:m_linkd.getQueryManager().getAllBroadcastDomains()) {
+            System.err.println(bd.printTopology());
+        }
+        
         assertEquals(3, m_linkd.getQueryManager().getAllBroadcastDomains().size());
+
         BroadcastDomain nodeAbd = m_linkd.getQueryManager().getBroadcastDomain(nodeA.getId().intValue());
         assertNotNull(nodeAbd);
         BroadcastDomain nodeBbd = m_linkd.getQueryManager().getBroadcastDomain(nodeB.getId().intValue());
         BroadcastDomain nodeCbd = m_linkd.getQueryManager().getBroadcastDomain(nodeC.getId().intValue());
         assertEquals(nodeAbd, nodeBbd);
         assertEquals(nodeAbd, nodeCbd);
-        nodeAbd.hierarchySetUp(nodeAbd.getBridge(nodeA.getId()));
+        BroadcastDomain.hierarchySetUp(nodeAbd,nodeAbd.getBridge(nodeA.getId()));
 
         topology.checkwithshared(nodeAbd);
         assertEquals(0, nodeAbd.getForwarders(topology.nodeAId).size());
@@ -477,36 +504,38 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         
         List<SharedSegment> nodeASegments = m_bridgeTopologyDao.getBridgeSharedSegments(nodeA.getId());
         assertEquals(2, nodeASegments.size());
-        
-        System.err.println(nodeAbd.printTopology());
-        
+
+        List<SharedSegment> nodeCSegments = m_bridgeTopologyDao.getBridgeSharedSegments(nodeC.getId());
+        assertEquals(2, nodeCSegments.size());
+
+        List<SharedSegment> nodeBSegments = m_bridgeTopologyDao.getBridgeSharedSegments(nodeB.getId());
+        assertEquals(3, nodeBSegments.size());
+
         BroadcastDomain nodeDbd = m_linkd.getQueryManager().getBroadcastDomain(nodeD.getId().intValue());
         assertNotNull(nodeDbd);
         BroadcastDomain nodeEbd = m_linkd.getQueryManager().getBroadcastDomain(nodeE.getId().intValue());
         assertEquals(nodeDbd, nodeEbd);
         
         assertEquals(2, nodeDbd.getBridges().size());
-        assertEquals(1, nodeDbd.getTopology().size());
-        assertTrue(nodeDbd.containBridgeId(nodeD.getId()));
-        assertTrue(nodeDbd.containBridgeId(nodeE.getId()));
-        SharedSegment deSegment = nodeDbd.getTopology().iterator().next();
+        assertEquals(1, nodeDbd.getSharedSegments().size());
+        assertNotNull(nodeDbd.getBridge(nodeD.getId()));
+        assertNotNull(nodeDbd.getBridge(nodeE.getId()));
+        SharedSegment deSegment = nodeDbd.getSharedSegments().iterator().next();
         assertEquals(2,deSegment.getBridgePortsOnSegment().size());
         assertEquals(1,deSegment.getMacsOnSegment().size());
-        assertEquals(45,deSegment.getPortForBridge(nodeD.getId()).intValue());
-        assertEquals(54,deSegment.getPortForBridge(nodeE.getId()).intValue());
+        assertEquals(45,deSegment.getBridgePort(nodeD.getId()).getBridgePort().intValue());
+        assertEquals(54,deSegment.getBridgePort(nodeE.getId()).getBridgePort().intValue());
         assertTrue(deSegment.containsMac(topology.shar));
 
-        System.err.println(nodeDbd.printTopology());
-
         BroadcastDomain nodeKbd = m_linkd.getQueryManager().getBroadcastDomain(nodeK.getId().intValue());
         assertNotNull(nodeKbd);
         assertEquals(1, nodeKbd.getBridges().size());
-        assertEquals(1, nodeKbd.getTopology().size());
-        assertTrue(nodeKbd.containBridgeId(nodeK.getId()));
-        SharedSegment kSegment = nodeKbd.getTopology().iterator().next();
+        assertEquals(1, nodeKbd.getSharedSegments().size());
+        assertNotNull(nodeKbd.getBridge(nodeK.getId()));
+        SharedSegment kSegment = nodeKbd.getSharedSegments().iterator().next();
         assertEquals(1,kSegment.getBridgePortsOnSegment().size());
         assertEquals(2,kSegment.getMacsOnSegment().size());
-        assertEquals(1099,kSegment.getPortForBridge(nodeK.getId()).intValue());
+        assertEquals(1099,kSegment.getBridgePort(nodeK.getId()).getBridgePort().intValue());
         assertTrue(kSegment.containsMac(topology.shar));
         assertTrue(kSegment.containsMac("1234567800aa"));
 
@@ -515,7 +544,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
     }    
     
     @Test
-    public void testDeleteBridgeC() {
+    public void testDeleteBridgeC() throws BridgeTopologyException {
         ABCTopology topology = new ABCTopology();
         NetworkBuilder nb = new NetworkBuilder();
         nb.addNode("nodeA").setForeignSource("linkd").setForeignId("nodeA").setSysObjectId("0.0").setSysName("nodeA").setType(NodeType.ACTIVE);
@@ -563,6 +592,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         mac1.setNode(nodeA);
         mac1.setBridgePort(topology.portA);
         mac1.setMacAddress(topology.mac1);
+        mac1.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac1.setBridgeMacLinkLastPollTime(mac1.getBridgeMacLinkCreateTime());
         m_bridgeMacLinkDao.save(mac1);
 
@@ -570,6 +600,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         mac2.setNode(nodeB);
         mac2.setBridgePort(topology.portB);
         mac2.setMacAddress(topology.mac2);
+        mac2.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac2.setBridgeMacLinkLastPollTime(mac2.getBridgeMacLinkCreateTime());
         m_bridgeMacLinkDao.save(mac2);
 
@@ -577,6 +608,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         mac3.setNode(nodeC);
         mac3.setBridgePort(topology.portC);
         mac3.setMacAddress(topology.mac3);
+        mac3.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac3.setBridgeMacLinkLastPollTime(mac3.getBridgeMacLinkCreateTime());
         m_bridgeMacLinkDao.save(mac3);
 
@@ -597,13 +629,13 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         BroadcastDomain nodeCbd = m_linkd.getQueryManager().getBroadcastDomain(nodeC.getId().intValue());
         assertNotNull(nodeCbd);
         assertEquals(nodeAbd, nodeCbd);
-        assertTrue(nodeAbd.hasRootBridge());
-        assertEquals(nodeAbd.getRootBridgeId().intValue(), nodeB.getId().intValue());
-        assertTrue(nodeAbd.containBridgeId(nodeA.getId()));
-        assertTrue(nodeAbd.containBridgeId(nodeB.getId()));
-        assertTrue(nodeAbd.containBridgeId(nodeC.getId()));
-        nodeAbd.hierarchySetUp(nodeAbd.getBridge(nodeA.getId()));
-        assertNotNull(nodeAbd.getRootBridgeId());
+        assertNotNull(nodeAbd.getRootBridge());
+        assertEquals(nodeAbd.getRootBridge().getNodeId().intValue(), nodeB.getId().intValue());
+        assertNotNull(nodeAbd.getBridge(nodeA.getId()));
+        assertNotNull(nodeAbd.getBridge(nodeB.getId()));
+        assertNotNull(nodeAbd.getBridge(nodeC.getId()));
+        BroadcastDomain.hierarchySetUp(nodeAbd,nodeAbd.getBridge(nodeA.getId()));
+        assertNotNull(nodeAbd.getRootBridge());
         topology.check(nodeAbd);
         
         m_linkd.deleteNode(nodeC.getId());
@@ -615,7 +647,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
     }
     
     @Test
-    public void testDeleteBridgeB() {
+    public void testDeleteBridgeB() throws BridgeTopologyException  {
         ABCTopology topology = new ABCTopology();
         NetworkBuilder nb = new NetworkBuilder();
         nb.addNode("nodeA").setForeignSource("linkd").setForeignId("nodeA").setSysObjectId("0.0").setSysName("nodeA").setType(NodeType.ACTIVE);
@@ -663,6 +695,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         mac1.setNode(nodeA);
         mac1.setBridgePort(topology.portA);
         mac1.setMacAddress(topology.mac1);
+        mac1.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac1.setBridgeMacLinkLastPollTime(mac1.getBridgeMacLinkCreateTime());
         m_bridgeMacLinkDao.save(mac1);
 
@@ -670,6 +703,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         mac2.setNode(nodeB);
         mac2.setBridgePort(topology.portB);
         mac2.setMacAddress(topology.mac2);
+        mac2.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac2.setBridgeMacLinkLastPollTime(mac2.getBridgeMacLinkCreateTime());
         m_bridgeMacLinkDao.save(mac2);
 
@@ -677,6 +711,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         mac3.setNode(nodeC);
         mac3.setBridgePort(topology.portC);
         mac3.setMacAddress(topology.mac3);
+        mac3.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac3.setBridgeMacLinkLastPollTime(mac3.getBridgeMacLinkCreateTime());
         m_bridgeMacLinkDao.save(mac3);
 
@@ -695,13 +730,13 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         BroadcastDomain nodeCbd = m_linkd.getQueryManager().getBroadcastDomain(nodeC.getId().intValue());
         assertEquals(nodeAbd, nodeBbd);
         assertEquals(nodeAbd, nodeCbd);
-        assertTrue(nodeAbd.hasRootBridge());
-        assertEquals(nodeAbd.getRootBridge().getId().intValue(), nodeA.getId().intValue());
-        assertTrue(nodeAbd.containBridgeId(nodeA.getId()));
-        assertTrue(nodeAbd.containBridgeId(nodeB.getId()));
-        assertTrue(nodeAbd.containBridgeId(nodeC.getId()));
-        nodeAbd.hierarchySetUp(nodeAbd.getBridge(nodeA.getId()));
-        assertNotNull(nodeAbd.getRootBridgeId());
+        assertNotNull(nodeAbd.getRootBridge());
+        assertEquals(nodeAbd.getRootBridge().getNodeId().intValue(), nodeA.getId().intValue());
+        assertNotNull(nodeAbd.getBridge(nodeA.getId()));
+        assertNotNull(nodeAbd.getBridge(nodeB.getId()));
+        assertNotNull(nodeAbd.getBridge(nodeC.getId()));
+        BroadcastDomain.hierarchySetUp(nodeAbd,nodeAbd.getBridge(nodeA.getId()));
+        assertNotNull(nodeAbd.getRootBridge());
         topology.check(nodeAbd);
 
         assertTrue(m_linkd.scheduleNodeCollection(nodeB.getId()));
@@ -715,7 +750,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
     }
     
     @Test
-    public void testDeleteBridgeA() {
+    public void testDeleteBridgeA() throws BridgeTopologyException {
         ABCTopology topology = new ABCTopology();
         NetworkBuilder nb = new NetworkBuilder();
         nb.addNode("nodeA").setForeignSource("linkd").setForeignId("nodeA").setSysObjectId("0.0").setSysName("nodeA").setType(NodeType.ACTIVE);
@@ -763,6 +798,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         mac1.setNode(nodeA);
         mac1.setBridgePort(topology.portA);
         mac1.setMacAddress(topology.mac1);
+        mac1.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac1.setBridgeMacLinkLastPollTime(mac1.getBridgeMacLinkCreateTime());
         m_bridgeMacLinkDao.save(mac1);
 
@@ -770,6 +806,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         mac2.setNode(nodeB);
         mac2.setBridgePort(topology.portB);
         mac2.setMacAddress(topology.mac2);
+        mac2.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac2.setBridgeMacLinkLastPollTime(mac2.getBridgeMacLinkCreateTime());
         m_bridgeMacLinkDao.save(mac2);
 
@@ -777,6 +814,7 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         mac3.setNode(nodeC);
         mac3.setBridgePort(topology.portC);
         mac3.setMacAddress(topology.mac3);
+        mac3.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
         mac3.setBridgeMacLinkLastPollTime(mac3.getBridgeMacLinkCreateTime());
         m_bridgeMacLinkDao.save(mac3);
 
@@ -795,17 +833,16 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         BroadcastDomain nodeCbd = m_linkd.getQueryManager().getBroadcastDomain(nodeC.getId().intValue());
         assertEquals(nodeAbd, nodeBbd);
         assertEquals(nodeAbd, nodeCbd);
-        assertTrue(nodeAbd.hasRootBridge());
-        assertEquals(nodeAbd.getRootBridge().getId().intValue(), nodeA.getId().intValue());
-        assertTrue(nodeAbd.containBridgeId(nodeA.getId()));
-        assertTrue(nodeAbd.containBridgeId(nodeB.getId()));
-        assertTrue(nodeAbd.containBridgeId(nodeC.getId()));
-        nodeAbd.hierarchySetUp(nodeAbd.getBridge(nodeA.getId()));
-        assertNotNull(nodeAbd.getRootBridgeId());
+        assertNotNull(nodeAbd.getRootBridge());
+        assertEquals(nodeAbd.getRootBridge().getNodeId().intValue(), nodeA.getId().intValue());
+        assertNotNull(nodeAbd.getBridge(nodeA.getId()));
+        assertNotNull(nodeAbd.getBridge(nodeB.getId()));
+        assertNotNull(nodeAbd.getBridge(nodeC.getId()));
+        BroadcastDomain.hierarchySetUp(nodeAbd,nodeAbd.getBridge(nodeA.getId()));
+        assertNotNull(nodeAbd.getRootBridge());
         topology.check(nodeAbd);
 
         assertTrue(m_linkd.scheduleNodeCollection(nodeA.getId()));
-        m_linkd.scheduleBridgeTopologyDiscovery(nodeA.getId());
         
         m_linkd.deleteNode(nodeA.getId());
         assertEquals(1, m_linkd.getQueryManager().getAllBroadcastDomains().size());
@@ -814,6 +851,286 @@ public class EnLinkdIT extends EnLinkdBuilderITCase {
         topology.checkBC(domain);
         
     }
+    
+    @Test
+    public void checkBridgeTopologyDao() throws BridgeTopologyException {
+        
+        NetworkBuilder nb = new NetworkBuilder();
+        nb.addNode("pe01").
+            setForeignSource("linkd").
+            setForeignId("pe01").
+            setSysObjectId(".1.3.6.1.4.1.9.1.1252").
+            setSysName("pe01").
+            setType(NodeType.ACTIVE);
+        nb.addInterface("10.25.39.1").setIsSnmpPrimary("P").setIsManaged("M");
+        m_nodeDao.save(nb.getCurrentNode());
+        
+        nb.addNode("asw01").
+            setForeignSource("linkd").
+            setForeignId("asw01").
+            setSysObjectId(".1.3.6.1.4.1.6486.800.1.1.2.1.10.1.1").
+            setSysName("asw01").
+            setType(NodeType.ACTIVE);
+        nb.addInterface("10.25.39.1").setIsSnmpPrimary("P").setIsManaged("M");
+        m_nodeDao.save(nb.getCurrentNode());
+        
+        nb.addNode("ess01").
+            setForeignSource("linkd").
+            setForeignId("ess01").
+            setSysObjectId(".1.3.6.1.4.1.8072.3.2.10").
+            setSysName("ess01").
+            setType(NodeType.ACTIVE);
+        nb.addInterface("10.25.39.34").setIsSnmpPrimary("P").setIsManaged("M");
+        nb.addInterface("10.25.139.61").setIsSnmpPrimary("N").setIsManaged("M");
+        m_nodeDao.save(nb.getCurrentNode());
+
+        OnmsNode pe01 = m_nodeDao.findByForeignId("linkd", "pe01");
+        OnmsNode asw01 = m_nodeDao.findByForeignId("linkd", "asw01");
+        OnmsNode ess01 = m_nodeDao.findByForeignId("linkd", "ess01");
+        
+        String mac0="00176301092d"; //mac of ess01
+        String mac1="54a050847462";
+        String mac2="a0d3c1333de9";
+        String mac3="e48d8c2e100c";
+        String mac4="0012cf68d780";
+        String mac5="e48d8cf17bcb"; //no ip address
+        String mac6="4c0082245938";
+        String mac7="4c0082245937";
+        IpNetToMedia ip1mac0 = new IpNetToMedia();
+        ip1mac0.setSourceNode(pe01);
+        ip1mac0.setSourceIfIndex(25);
+        ip1mac0.setPhysAddress(mac0);
+        ip1mac0.setNetAddress(InetAddressUtils.addr("10.25.39.34"));
+        ip1mac0.setLastPollTime(ip1mac0.getCreateTime());
+        
+        ip1mac0.setIpNetToMediaType(IpNetToMediaType.IPNETTOMEDIA_TYPE_DYNAMIC);
+        IpNetToMedia ip2mac0 = new IpNetToMedia();
+        ip2mac0.setSourceNode(pe01);
+        ip2mac0.setSourceIfIndex(25);
+        ip2mac0.setPhysAddress(mac0);
+        ip2mac0.setNetAddress(InetAddressUtils.addr("10.25.139.61"));
+        ip2mac0.setIpNetToMediaType(IpNetToMediaType.IPNETTOMEDIA_TYPE_DYNAMIC);
+        ip2mac0.setLastPollTime(ip2mac0.getCreateTime());
+        IpNetToMedia ip1mac1 = new IpNetToMedia();
+        ip1mac1.setSourceNode(pe01);
+        ip1mac1.setSourceIfIndex(3001);
+        ip1mac1.setPhysAddress(mac1);
+        ip1mac1.setNetAddress(InetAddressUtils.addr("172.22.128.109"));
+        ip1mac1.setIpNetToMediaType(IpNetToMediaType.IPNETTOMEDIA_TYPE_DYNAMIC);
+        ip1mac1.setLastPollTime(ip1mac1.getCreateTime());
+
+        IpNetToMedia ip1mac2 = new IpNetToMedia();
+        ip1mac2.setSourceNode(pe01);
+        ip1mac2.setSourceIfIndex(3001);
+        ip1mac2.setPhysAddress(mac2);
+        ip1mac2.setNetAddress(InetAddressUtils.addr("172.22.128.115"));
+        ip1mac2.setIpNetToMediaType(IpNetToMediaType.IPNETTOMEDIA_TYPE_DYNAMIC);
+        ip1mac2.setLastPollTime(ip1mac2.getCreateTime());
+        IpNetToMedia ip1mac3 = new IpNetToMedia();
+        ip1mac3.setSourceNode(pe01);
+        ip1mac3.setSourceIfIndex(3072);
+        ip1mac3.setPhysAddress(mac3);
+        ip1mac3.setNetAddress(InetAddressUtils.addr("10.125.39.18"));
+        ip1mac3.setIpNetToMediaType(IpNetToMediaType.IPNETTOMEDIA_TYPE_DYNAMIC);
+        ip1mac3.setLastPollTime(ip1mac3.getCreateTime());
+        IpNetToMedia ip2mac3 = new IpNetToMedia();
+        ip2mac3.setSourceNode(pe01);
+        ip2mac3.setSourceIfIndex(3072);
+        ip2mac3.setPhysAddress(mac3);
+        ip2mac3.setNetAddress(InetAddressUtils.addr("10.125.39.5"));
+        ip2mac3.setIpNetToMediaType(IpNetToMediaType.IPNETTOMEDIA_TYPE_DYNAMIC);
+        ip2mac3.setLastPollTime(ip2mac3.getCreateTime());
+        IpNetToMedia ip3mac3 = new IpNetToMedia();
+        ip3mac3.setSourceNode(pe01);
+        ip3mac3.setSourceIfIndex(3072);
+        ip3mac3.setPhysAddress(mac3);
+        ip3mac3.setNetAddress(InetAddressUtils.addr("10.125.39.133"));
+        ip3mac3.setIpNetToMediaType(IpNetToMediaType.IPNETTOMEDIA_TYPE_DYNAMIC);
+        ip3mac3.setLastPollTime(ip3mac3.getCreateTime());
+        IpNetToMedia ip1mac4 = new IpNetToMedia();
+        ip1mac4.setSourceNode(pe01);
+        ip1mac4.setSourceIfIndex(3072);
+        ip1mac4.setPhysAddress(mac4);
+        ip1mac4.setNetAddress(InetAddressUtils.addr("10.25.39.61"));
+        ip1mac4.setIpNetToMediaType(IpNetToMediaType.IPNETTOMEDIA_TYPE_DYNAMIC);
+        ip1mac4.setLastPollTime(ip1mac4.getCreateTime());
+        IpNetToMedia ip1mac6 = new IpNetToMedia();
+        ip1mac6.setSourceNode(pe01);
+        ip1mac6.setSourceIfIndex(8011);
+        ip1mac6.setPhysAddress(mac6);
+        ip1mac6.setNetAddress(InetAddressUtils.addr("10.101.39.2"));
+        ip1mac6.setIpNetToMediaType(IpNetToMediaType.IPNETTOMEDIA_TYPE_DYNAMIC);
+        ip1mac6.setLastPollTime(ip1mac6.getCreateTime());
+
+        m_ipNetToMediaDao.save(ip1mac0);
+        m_ipNetToMediaDao.save(ip2mac0);
+        m_ipNetToMediaDao.save(ip1mac1);
+        m_ipNetToMediaDao.save(ip1mac2);
+        m_ipNetToMediaDao.save(ip1mac3);
+        m_ipNetToMediaDao.save(ip2mac3);
+        m_ipNetToMediaDao.save(ip3mac3);
+        m_ipNetToMediaDao.save(ip1mac4);      
+        m_ipNetToMediaDao.save(ip1mac6);      
+        
+        BridgeBridgeLink asw01pe01link = new BridgeBridgeLink();
+        asw01pe01link.setNode(asw01);
+        asw01pe01link.setBridgePort(24);
+        asw01pe01link.setBridgePort(1024);
+        asw01pe01link.setDesignatedNode(pe01);
+        asw01pe01link.setDesignatedPort(24);
+        asw01pe01link.setDesignatedPortIfIndex(10124);
+        asw01pe01link.setDesignatedVlan(25);
+        asw01pe01link.setBridgeBridgeLinkLastPollTime(asw01pe01link.getBridgeBridgeLinkCreateTime());
+        BridgeMacLink pe01mac1port3 = new BridgeMacLink();
+        pe01mac1port3.setNode(pe01);
+        pe01mac1port3.setBridgePort(3);
+        pe01mac1port3.setBridgePortIfIndex(10103);
+        pe01mac1port3.setVlan(3001);
+        pe01mac1port3.setMacAddress(mac1);
+        pe01mac1port3.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
+        pe01mac1port3.setBridgeMacLinkLastPollTime(pe01mac1port3.getBridgeMacLinkCreateTime());
+        BridgeMacLink pe01mac2port3 = new BridgeMacLink();
+        pe01mac2port3.setNode(pe01);
+        pe01mac2port3.setBridgePort(3);
+        pe01mac2port3.setBridgePortIfIndex(10103);
+        pe01mac2port3.setVlan(3001);
+        pe01mac2port3.setMacAddress(mac2);
+        pe01mac2port3.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
+        pe01mac2port3.setBridgeMacLinkLastPollTime(pe01mac2port3.getBridgeMacLinkCreateTime());
+        BridgeMacLink pe01mac3port7 = new BridgeMacLink();
+        pe01mac3port7.setNode(pe01);
+        pe01mac3port7.setBridgePort(7);
+        pe01mac3port7.setBridgePortIfIndex(10107);
+        pe01mac3port7.setVlan(3072);
+        pe01mac3port7.setMacAddress(mac3);
+        pe01mac3port7.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
+        pe01mac3port7.setBridgeMacLinkLastPollTime(pe01mac3port7.getBridgeMacLinkCreateTime());
+        BridgeMacLink asw01mac4port1 = new BridgeMacLink();
+        asw01mac4port1.setNode(asw01);
+        asw01mac4port1.setBridgePort(1);
+        asw01mac4port1.setBridgePortIfIndex(1001);
+        asw01mac4port1.setMacAddress(mac4);
+        asw01mac4port1.setLinkType(BridgeMacLinkType.BRIDGE_LINK);        
+        asw01mac4port1.setBridgeMacLinkLastPollTime(asw01mac4port1.getBridgeMacLinkCreateTime());
+        BridgeMacLink asw01mac5port1 = new BridgeMacLink();
+        asw01mac5port1.setNode(asw01);
+        asw01mac5port1.setBridgePort(1);
+        asw01mac5port1.setBridgePortIfIndex(1001);
+        asw01mac5port1.setMacAddress(mac5);
+        asw01mac5port1.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
+        asw01mac5port1.setBridgeMacLinkLastPollTime(asw01mac5port1.getBridgeMacLinkCreateTime());
+        BridgeMacLink asw01mac0port1 = new BridgeMacLink();
+        asw01mac0port1.setNode(asw01);
+        asw01mac0port1.setBridgePort(1);
+        asw01mac0port1.setBridgePortIfIndex(1001);
+        asw01mac0port1.setMacAddress(mac0);
+        asw01mac0port1.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
+        asw01mac0port1.setBridgeMacLinkLastPollTime(asw01mac0port1.getBridgeMacLinkCreateTime());
+        BridgeMacLink asw01mac6port19 = new BridgeMacLink();
+        asw01mac6port19.setNode(asw01);
+        asw01mac6port19.setBridgePort(19);
+        asw01mac6port19.setBridgePortIfIndex(1019);
+        asw01mac6port19.setMacAddress(mac6);
+        asw01mac6port19.setLinkType(BridgeMacLinkType.BRIDGE_LINK);
+        asw01mac6port19.setBridgeMacLinkLastPollTime(asw01mac6port19.getBridgeMacLinkCreateTime());
+
+        BridgeMacLink shared = new BridgeMacLink();
+        shared.setNode(pe01);
+        shared.setBridgePort(24);
+        shared.setBridgePortIfIndex(10124);
+        shared.setMacAddress(mac7);
+        shared.setLinkType(BridgeMacLinkType.BRIDGE_LINK);        
+        shared.setBridgeMacLinkLastPollTime(shared.getBridgeMacLinkCreateTime());
+        
+        m_bridgeBridgeLinkDao.save(asw01pe01link);
+        m_bridgeMacLinkDao.save(shared);
+        m_bridgeMacLinkDao.save(pe01mac1port3);
+        m_bridgeMacLinkDao.save(pe01mac2port3);
+        m_bridgeMacLinkDao.save(pe01mac3port7);
+        m_bridgeMacLinkDao.save(asw01mac0port1);
+        m_bridgeMacLinkDao.save(asw01mac4port1);
+        m_bridgeMacLinkDao.save(asw01mac5port1);
+        m_bridgeMacLinkDao.save(asw01mac6port19);
+
+        m_ipNetToMediaDao.flush();
+        m_bridgeBridgeLinkDao.flush();
+        m_bridgeMacLinkDao.flush();
+
+        assertEquals(1,m_bridgeTopologyDao.load().size());
+        assertEquals(3,m_bridgeTopologyDao.getBridgeSharedSegments(pe01.getId()).size());
+        assertEquals(3,m_bridgeTopologyDao.getBridgeSharedSegments(asw01.getId()).size());
+        assertEquals(0,m_bridgeTopologyDao.getBridgeSharedSegments(ess01.getId()).size());
+        
+        
+        SharedSegment asw01port1segment = m_bridgeTopologyDao.getHostSharedSegment(mac0);
+        assertEquals(3,asw01port1segment.getMacsOnSegment().size());
+        assertTrue(asw01port1segment.containsMac(mac0));
+        assertTrue(asw01port1segment.containsMac(mac4));
+        assertTrue(asw01port1segment.containsMac(mac5));
+        assertEquals(1, asw01port1segment.getBridgePortsOnSegment().size());
+        BridgePort asw01port1 = asw01port1segment.getBridgePortsOnSegment().iterator().next();
+        assertEquals(asw01.getId(), asw01port1.getNodeId());
+        assertEquals(1, asw01port1.getBridgePort().intValue());
+        assertEquals(1001, asw01port1.getBridgePortIfIndex().intValue());
+        
+        SharedSegment pe01port3 = m_bridgeTopologyDao.getHostSharedSegment(mac1);
+        assertEquals(2,pe01port3.getMacsOnSegment().size());
+        assertTrue(pe01port3.containsMac(mac1));
+        assertTrue(pe01port3.containsMac(mac2));
+        assertEquals(1, pe01port3.getBridgePortsOnSegment().size());
+
+        SharedSegment pe01port7 = m_bridgeTopologyDao.getHostSharedSegment(mac3);
+        assertEquals(1,pe01port7.getMacsOnSegment().size());
+        assertTrue(pe01port7.containsMac(mac3));
+        assertEquals(1, pe01port7.getBridgePortsOnSegment().size());
+
+        SharedSegment asw01port19segment = m_bridgeTopologyDao.getHostSharedSegment(mac6);
+        assertEquals(1,asw01port19segment.getMacsOnSegment().size());
+        assertTrue(asw01port19segment.containsMac(mac6));
+        assertEquals(1, asw01port19segment.getBridgePortsOnSegment().size());
+
+        SharedSegment pe01asw01segment = m_bridgeTopologyDao.getHostSharedSegment(mac7);
+        assertEquals(1,pe01asw01segment.getMacsOnSegment().size());
+        assertTrue(pe01asw01segment.containsMac(mac7));
+        assertEquals(2, pe01asw01segment.getBridgePortsOnSegment().size());
+
+        SharedSegment emptysegment = m_bridgeTopologyDao.getHostSharedSegment("001763010920");
+        assertEquals(0, emptysegment.getBridgePortsOnSegment().size());
+        assertEquals(0, emptysegment.getMacsOnSegment().size());
+        
+        //This code is inherited from EnlinkElementFactory
+        Map<String, List<OnmsIpInterface>> mactoIpNodeMap = new HashMap<String, List<OnmsIpInterface>>();
+        m_ipInterfaceDao.findByNodeId(ess01.getId()).stream().forEach( ip -> {
+            m_ipNetToMediaDao.findByNetAddress(ip.getIpAddress()).stream().forEach( ipnettomedia -> {
+                if (!mactoIpNodeMap.containsKey(ipnettomedia.getPhysAddress()))
+                    mactoIpNodeMap.put(ipnettomedia.getPhysAddress(),
+                                   new ArrayList<OnmsIpInterface>());
+                mactoIpNodeMap.get(ipnettomedia.getPhysAddress()).add(ip);
+            });
+        });
+        
+        assertEquals(1, mactoIpNodeMap.size());
+        assertEquals(mac0, mactoIpNodeMap.keySet().iterator().next());
+        Set<String> ipsonmap = new HashSet<String>();
+        mactoIpNodeMap.get(mac0).stream().forEach(onmsip -> ipsonmap.add(str(onmsip.getIpAddress())));
+        assertEquals(2, ipsonmap.size());
+        assertTrue(ipsonmap.contains("10.25.39.34"));
+        assertTrue(ipsonmap.contains("10.25.139.61"));   
+        
+        Set<Integer> nodelinks = new HashSet<Integer>();
+        for (String mac : mactoIpNodeMap.keySet()) {
+            SharedSegment segment = m_bridgeTopologyDao.getHostSharedSegment(mac);
+            if (segment.isEmpty()) {
+                continue;
+            }
+            nodelinks.add(segment.getDesignatedBridge());
+        }
+       
+        assertEquals(1, nodelinks.size());
+        assertEquals(asw01.getId(), nodelinks.iterator().next());
+        
+    }
+    
 
 
 }
